# -*- coding: UTF-8 -*-
from __future__ import unicode_literals
from django.apps import apps
from django import template

register = template.Library()


@register.inclusion_tag('include_by_ajax/includes/placeholder.html', takes_context=True)
def include_by_ajax(context, template_name, placeholder_template_name=None):
    # get the app configuration
    app_config = apps.get_app_config('include_by_ajax')
    # get User-Agent
    request = context['request']
    user_agent = request.META.get('HTTP_USER_AGENT') or ''
    # check if the current request is coming from a web crawler
    is_web_crawler = bool(app_config.web_crawler_pattern.search(user_agent))
    # in case of web crawler or an Ajax call we'll do full render
    context['include_by_ajax_full_render'] = bool(
        is_web_crawler or
        request.is_ajax() and request.GET.get('include_by_ajax_full_render')
    )
    # in case of web crawler, the placeholder shouldn't be wrapped with a <section>
    context['include_by_ajax_no_placeholder_wrapping'] = is_web_crawler
    # pass down the template paths
    context['template_name'] = template_name
    context['placeholder_template_name'] = placeholder_template_name
    return context



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals

import re

from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _
from django.conf import settings


class IncludeByAjaxConfig(AppConfig):
    name = 'include_by_ajax'
    verbose_name = _("Include by Ajax")

    WEB_CRAWLERS = getattr(settings, 'INCLUDE_BY_AJAX_WEB_CRAWLERS', (
        'Googlebot', # Google bot
        'Bingbot', # Bing bot
        'Slurp', # Yahoo! bot
        'DuckDuckBot', # Duck Duck Go bot
        'Baiduspider', # Baidu bot
        'YandexBot', # Yandex bot
        'Sogou', # Sogou bot
        'Exabot', # Exalead bot
        'ia_archiver', # Alexa bot
    ))
    web_crawler_pattern = re.compile('|'.join(sorted(WEB_CRAWLERS, reverse=True)), flags=re.IGNORECASE)

    def ready(self):
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


with open('README.md') as readme_file:
    readme = readme_file.read()

requirements = [
    'Django>=1.8,<2.3',
]

setup(
    author="Aidas Bendoraitis",
    author_email='aidasbend@yahoo.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    description="A Django App Providing the `{% include_by_ajax %}` Template Tag",
    install_requires=requirements,
    license="MIT license",
    long_description=readme,
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords='django_include_by_ajax',
    name='django-include-by-ajax',
    packages=find_packages(include=['include_by_ajax']),
    url='https://github.com/archatas/django-include-by-ajax',
    version='1.0.0',
    zip_safe=False,
)



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals

from django.test import TestCase
from django.test.client import RequestFactory

from include_by_ajax.templatetags.include_by_ajax_tags import include_by_ajax


class IncludeByAjaxTemplateTagTests(TestCase):
    @classmethod
    def setUpClass(cls):
        cls.factory = RequestFactory()

    @classmethod
    def tearDownClass(cls):
        pass

    def test_first_access(self):
        # Given a request without any special query parameters and a template name
        request = self.factory.get('/')
        template_name = 'included.html'

        # When template tag {% include_by_ajax %} is called
        context = include_by_ajax(context={'request': request}, template_name=template_name)

        # Then we should get the template name saved in context variables
        self.assertEquals(context['include_by_ajax_no_placeholder_wrapping'], False)
        self.assertEquals(context['include_by_ajax_full_render'], False)
        self.assertEquals(context['template_name'], template_name)
        self.assertEquals(context['placeholder_template_name'], None)

    def test_first_access_with_loading_template(self):
        # Given a request without any special query parameters
        # and a template names for including and for temporary showing
        request = self.factory.get('/')
        template_name = 'included.html'
        placeholder_template_name = 'loading.html'

        # When template tag {% include_by_ajax %} is called
        context = include_by_ajax(
            context={'request': request},
            template_name=template_name,
            placeholder_template_name=placeholder_template_name,
        )

        # Then we should get the template names saved in context variables
        self.assertEquals(context['include_by_ajax_no_placeholder_wrapping'], False)
        self.assertEquals(context['include_by_ajax_full_render'], False)
        self.assertEquals(context['template_name'], template_name)
        self.assertEquals(context['placeholder_template_name'], placeholder_template_name)

    def test_access_by_ajax(self):
        # Given a request with include_by_ajax_full_render=1 query parameter and a template name
        request = self.factory.get('/', {
            'include_by_ajax_full_render': '1',
        }, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
        template_name = 'included.html'

        # When template tag {% include_by_ajax %} is called
        context = include_by_ajax(context={'request': request}, template_name=template_name)

        # Then we should get the template name and include_by_ajax_full_render saved in context variables
        self.assertEquals(context['include_by_ajax_no_placeholder_wrapping'], False)
        self.assertEquals(context['include_by_ajax_full_render'], True)
        self.assertEquals(context['template_name'], template_name)
        self.assertEquals(context['placeholder_template_name'], None)

    def test_access_by_ajax_with_loading_template(self):
        # Given a request with include_by_ajax_full_render=1
        # and template names for including and for temporary showing
        request = self.factory.get('/', {
            'include_by_ajax_full_render': '1',
        }, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
        template_name = 'included.html'
        placeholder_template_name = 'loading.html'

        # When template tag {% include_by_ajax %} is called
        context = include_by_ajax(
            context={'request': request},
            template_name=template_name,
            placeholder_template_name=placeholder_template_name,
        )

        # Then we should get the template names and include_by_ajax_full_render saved in context variables
        self.assertEquals(context['include_by_ajax_no_placeholder_wrapping'], False)
        self.assertEquals(context['include_by_ajax_full_render'], True)
        self.assertEquals(context['template_name'], template_name)
        self.assertEquals(context['placeholder_template_name'], placeholder_template_name)

    def test_web_crawler_access(self):
        # Given a request without special query parameters and a template name
        request = self.factory.get('/', HTTP_USER_AGENT='Googlebot')
        template_name = 'included.html'

        # When template tag {% include_by_ajax %} is called
        context = include_by_ajax(context={'request': request}, template_name=template_name)

        # Then we should get the template names, include_by_ajax_no_placeholder_wrapping,
        # and include_by_ajax_full_render saved in context variables
        self.assertEquals(context['include_by_ajax_no_placeholder_wrapping'], True)
        self.assertEquals(context['include_by_ajax_full_render'], True)
        self.assertEquals(context['template_name'], template_name)
        self.assertEquals(context['placeholder_template_name'], None)
